@@ -18,6 +18,7 @@ import pkg_resources
 import urllib3
 import backoff
 import logging
+from math import nan
 from notebook.notebookapp import list_running_servers
 
 urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
@@ -458,6 +459,7 @@ class HubClient(OCSClient):
         verbose: bool = False,
         stored: bool = False,
         resume: bool = False,
+        max_stored_rows=MAX_STORED_DV_ROWS,
     ):
         df = pd.DataFrame()
         next_page = None
@@ -514,7 +516,7 @@ class HubClient(OCSClient):
                     )
                 else:
                     df = df.append(pd.read_json(json.dumps(csv_or_json)))
-                    if len(df) >= MAX_STORED_DV_ROWS:
+                    if len(df) >= max_stored_rows:
                         self.__dataview_next_page = next_page
                         print()
                         break
@@ -561,6 +563,7 @@ class HubClient(OCSClient):
         end_index: str,
         count: int = None,
         resume: bool = False,
+        max_rows=MAX_STORED_DV_ROWS,
     ):
         try:
             result = self.dataview_get_data_pd(
@@ -572,6 +575,7 @@ class HubClient(OCSClient):
                 count=count,
                 stored=True,
                 resume=resume,
+                max_stored_rows=max_rows,
             )
         except SdsError as e:
             if "404" in str(e):
